==> freerdp-2%3A2.5.0-1.1-aarch64.pkg.tar.xz: usr/lib/cmake/WinPR2/WinPRTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "winpr" for configuration "None"
set_property(TARGET winpr APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwinpr2.so.2.5.0"
  IMPORTED_SONAME_NONE "libwinpr2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS winpr )
list(APPEND _IMPORT_CHECK_FILES_FOR_winpr "${_IMPORT_PREFIX}/lib/libwinpr2.so.2.5.0" )

# Import target "winpr-tools" for configuration "None"
set_property(TARGET winpr-tools APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-tools PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwinpr-tools2.so.2.5.0"
  IMPORTED_SONAME_NONE "libwinpr-tools2.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS winpr-tools )
list(APPEND _IMPORT_CHECK_FILES_FOR_winpr-tools "${_IMPORT_PREFIX}/lib/libwinpr-tools2.so.2.5.0" )

# Import target "winpr-makecert" for configuration "None"
set_property(TARGET winpr-makecert APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-makecert PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/winpr-makecert"
  )

list(APPEND _IMPORT_CHECK_TARGETS winpr-makecert )
list(APPEND _IMPORT_CHECK_FILES_FOR_winpr-makecert "${_IMPORT_PREFIX}/bin/winpr-makecert" )

# Import target "winpr-hash" for configuration "None"
set_property(TARGET winpr-hash APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-hash PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/winpr-hash"
  )

list(APPEND _IMPORT_CHECK_TARGETS winpr-hash )
list(APPEND _IMPORT_CHECK_FILES_FOR_winpr-hash "${_IMPORT_PREFIX}/bin/winpr-hash" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> freerdp-2%3A2.11.2-1-aarch64.pkg.tar.xz: usr/lib/cmake/WinPR2/WinPRTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "winpr" for configuration "None"
set_property(TARGET winpr APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwinpr2.so.2.11.2"
  IMPORTED_SONAME_NONE "libwinpr2.so.2"
  )

list(APPEND _cmake_import_check_targets winpr )
list(APPEND _cmake_import_check_files_for_winpr "${_IMPORT_PREFIX}/lib/libwinpr2.so.2.11.2" )

# Import target "winpr-tools" for configuration "None"
set_property(TARGET winpr-tools APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-tools PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "winpr"
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwinpr-tools2.so.2.11.2"
  IMPORTED_SONAME_NONE "libwinpr-tools2.so.2"
  )

list(APPEND _cmake_import_check_targets winpr-tools )
list(APPEND _cmake_import_check_files_for_winpr-tools "${_IMPORT_PREFIX}/lib/libwinpr-tools2.so.2.11.2" )

# Import target "winpr-makecert" for configuration "None"
set_property(TARGET winpr-makecert APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-makecert PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/winpr-makecert"
  )

list(APPEND _cmake_import_check_targets winpr-makecert )
list(APPEND _cmake_import_check_files_for_winpr-makecert "${_IMPORT_PREFIX}/bin/winpr-makecert" )

# Import target "winpr-hash" for configuration "None"
set_property(TARGET winpr-hash APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(winpr-hash PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/bin/winpr-hash"
  )

list(APPEND _cmake_import_check_targets winpr-hash )
list(APPEND _cmake_import_check_files_for_winpr-hash "${_IMPORT_PREFIX}/bin/winpr-hash" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
